==> haskell-wai-websockets-3.0.1.1-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-BRmMsjWeE355cubfpCAzVw
key: wai-websockets-3.0.1.1-BRmMsjWeE355cubfpCAzVw
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 4cc27847339ab59ffe8e39a311f03b64
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-BRmMsjWeE355cubfpCAzVw
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG transformers-0.5.2.0
    wai-3.2.1.1-1k6hSu2jHMHEfd9vQlBLrn
    websockets-0.10.0.0-I9x2P0Y18D45EsTOwIhl0e
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.1-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-1MWqfyylZBZ4hIVFskTLz6
key: wai-websockets-3.0.1.1-1MWqfyylZBZ4hIVFskTLz6
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 72ffabd2ef15d3dc916ec7c20046aa8e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-1MWqfyylZBZ4hIVFskTLz6
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG transformers-0.5.2.0
    wai-3.2.1.1-1k6hSu2jHMHEfd9vQlBLrn
    websockets-0.10.0.0-AoyfYrPV8hG6nHQYTZmXVO
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
